package com.solution.system.mapper;

import java.util.List;
import com.solution.system.domain.Nodeconnection;

/**
 * 节点连接Mapper接口
 * 
 * @author ruoyi
 * @date 2026-02-05
 */
public interface NodeconnectionMapper 
{
    /**
     * 查询节点连接
     * 
     * @param id 节点连接主键
     * @return 节点连接
     */
    public Nodeconnection selectNodeconnectionById(Long id);

    /**
     * 查询节点连接列表
     * 
     * @param nodeconnection 节点连接
     * @return 节点连接集合
     */
    public List<Nodeconnection> selectNodeconnectionList(Nodeconnection nodeconnection);

    /**
     * 新增节点连接
     * 
     * @param nodeconnection 节点连接
     * @return 结果
     */
    public int insertNodeconnection(Nodeconnection nodeconnection);

    /**
     * 修改节点连接
     * 
     * @param nodeconnection 节点连接
     * @return 结果
     */
    public int updateNodeconnection(Nodeconnection nodeconnection);

    /**
     * 删除节点连接
     * 
     * @param id 节点连接主键
     * @return 结果
     */
    public int deleteNodeconnectionById(Long id);

    /**
     * 批量删除节点连接
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNodeconnectionByIds(Long[] ids);
}
